@@ -4,7 +4,7 @@ import numpy as np
 
 from worker import API
 from worker.app import TimeActivityModule
-from testcase.app import constants
+from testcase.app.app_constants import constants
 from worker.data.operations import nanround
 from worker.exceptions import Misconfigured
 
@@ -83,7 +83,7 @@ class SurfaceMSE(TimeActivityModule):
 
     def compute_average_mse(self, wits_records: List[dict], bit_size: float) -> float:
         """
-        TODO
+        Compute MSE for a list of drilling wits records
         :param wits_records: WITS records
         :param bit_size: bit size in INCH
         :return: MSE in PSI
@@ -129,7 +129,7 @@ def extract_bit_size(drillstring: dict) -> float:
     components = drillstring.get('data', {}).get('components', [])
     bit = list(filter(lambda x: x['family'] == 'bit', components))
     if not bit:
-        return Misconfigured(f"No bit in the drillstring: {drillstring}")
+        raise Misconfigured(f"No bit in the drillstring: {drillstring}")
     return bit[0].get('size', None)
 
 
