@@ -215,6 +215,19 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
             'collection': self.collection,
             'data': {}
         }
+
+        enable_output_type_field = constants.get(
+            "{}.{}.enable-output-type-field".format(self.app_key, self.module_key), False
+        )
+
+        if not enable_output_type_field:
+            return output
+
+        # If a specific module enforces type field in the output collection,
+        # build_empty_output adds an additional type field to the output.
+        # This can be enforced by setting "enable-output-type-field" to True in the module app constants.
+        output.update({'type': self.module_key})
+
         return output
 
     @staticmethod
