@@ -73,7 +73,16 @@ def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, li
     for collection in collections:
         path = "/v1/data/corva/%s" % collection
         query = "{asset_id#eq#%s}" % asset_id
-        worker.delete(path=path, query=query)
+
+        # Looping a maximum of 2000 times. Tries to delete a maximum of 7.2 million records.
+        for _ in range(2000):
+            # Upon delete API returns the following response {"deleted_count": 10000}
+            res = worker.delete(path=path, query=query, limit=3600, retry_count=1).data
+            records_deleted = res.get("deleted_count") or 0
+
+            # API currently deletes 10000 records at a time, if the deleted count is less than 3600, break loop
+            if records_deleted < 3600:
+                break
 
 
 def point_main_envs(env: str):
