@@ -1,8 +1,5 @@
-import json
 from typing import List, Union
 
-from cached_property import cached_property
-
 from worker.data.operations import get_data_by_path
 from worker.event import Event, EventType
 from worker.framework import constants
@@ -28,16 +25,6 @@ class StreamEvent(Event):
             default=None
         )
 
-    @cached_property
-    def is_posting_to_message_producer(self) -> bool:
-        """
-        Whether to post to message producer for the wits stream or not.
-        If there is no lambda app following your app then this should be false,
-        because this process is intracting with the API which slows the process down.
-        """
-        is_posting: bool = constants.get('global.post-to-message-producer', False)
-        return is_posting
-
     @classmethod
     def merge(cls, events: List['StreamEvent']) -> Union['StreamEvent', None]:
         """Merge stream events of the same asset id into one"""
@@ -63,9 +50,5 @@ class StreamEvent(Event):
             'data': self.records
         }
 
-    def complete_event(self, api):
-        if not self.is_posting_to_message_producer or not self.app_connection_id:
-            return
-
-        payload = self.build_message_producer_payload()
-        api.post(path='/v1/message_producer', data=json.dumps(payload))
+    def complete_event(self, api) -> None:
+        self.post_to_message_producer(api)
