@@ -53,7 +53,7 @@ class MongoStateHandler(StateHandler):
 
         return state.get("data", {}).get("state", {})
 
-    def save_state(self, asset_id: int, state: dict, state_key: str, timestamp: int):
+    def save_state(self, asset_id: int, state: dict, state_key: str, timestamp: int, **kwargs):
         """
         Save the state to mongo
         :param asset_id:
@@ -80,7 +80,6 @@ class MongoStateHandler(StateHandler):
 
         # if a blank state was loaded set the created timestamp to current timestamp
         record["timestamp"] = self.created_timestamp or timestamp
-
         response = self.api.post(path="/v1/data/corva", data=json.dumps(record)).data
 
         self.mongo_id = response.get("_id")
